package com.ynet.life.search.core;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.IOException;
import org.apache.lucene.document.Document;
import org.apache.lucene.index.CorruptIndexException;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.index.Term;

/* loaded from: com_ynet_life_search_core.jar:com/ynet/life/search/core/IndexBuilderImpl.class */
public class IndexBuilderImpl implements IndexBuilder {
    private final IndexWriter indexWriter;

    public IndexBuilderImpl(IndexSource indexSource) {
        this.indexWriter = indexSource.getIndexWriter();
    }

    @Override // com.ynet.life.search.core.IndexBuilder
    public void addDocument(Document document) throws TranFailException {
        addDocument(this.indexWriter, document);
    }

    @Override // com.ynet.life.search.core.IndexBuilder
    public void delDocuments(String field, String queryString) throws TranFailException {
        try {
            this.indexWriter.deleteDocuments(new Term(field, queryString));
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("删除文档时访问索引失败: '%s'", ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        }
    }

    private void addDocument(IndexWriter indexWriter, Document document) throws TranFailException {
        try {
            indexWriter.addDocument(document);
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("更新文档时访问索引失败: '%s', 原因是: '%s'", document.toString(), ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        }
    }

    @Override // com.ynet.life.search.core.IndexBuilder
    public int getDocCount() {
        return this.indexWriter.maxDoc();
    }

    @Override // com.ynet.life.search.core.IndexBuilder
    public void commit() throws TranFailException {
        try {
            this.indexWriter.commit();
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("提交修改时访问索引失败: '%s'", ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        } catch (CorruptIndexException cie) {
            Trace.logError("LifeSearch", String.format("索引已损坏: '%s'", cie.getMessage()), cie);
            throw new TranFailException(cie);
        }
    }

    @Override // com.ynet.life.search.core.IndexBuilder
    public void optimize() throws TranFailException {
        try {
            this.indexWriter.optimize();
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("优化时访问索引失败: '%s'", ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        } catch (CorruptIndexException cie) {
            Trace.logError("LifeSearch", String.format("索引已损坏: '%s'", cie.getMessage()), cie);
            throw new TranFailException(cie);
        }
    }

    @Override // com.ynet.life.search.core.IndexBuilder
    public void close() throws TranFailException {
        try {
            this.indexWriter.commit();
        } catch (IOException ioe) {
            Trace.logError("LifeSearch", String.format("提交修改时访问索引失败: '%s'", ioe.getMessage()), ioe);
            throw new TranFailException(ioe);
        } catch (CorruptIndexException cie) {
            Trace.logError("LifeSearch", String.format("索引已损坏: '%s'", cie.getMessage()), cie);
            throw new TranFailException(cie);
        }
    }
}
